@@ -4,7 +4,7 @@ import logging
 import time
 
 from dataclasses import dataclass
-from typing import Any, Callable, Dict, Optional
+from typing import Any, Callable, Coroutine, Dict, Optional
 
 from rap.common.aes import Crypto
 from rap.common.exceptions import (
@@ -21,10 +21,10 @@ from rap.common.utlis import (
     Constant,
     MISS_OBJECT,
     get_event_loop,
-    gen_id,
+    gen_random_time_id,
     parse_error,
 )
-from rap.conn.connection import ServerConnection
+from rap.common.conn import ServerConnection
 from rap.manager.aes_manager import aes_manager
 from rap.manager.client_manager import client_manager, ClientModel, LifeCycleEnum
 from rap.manager.func_manager import func_manager
@@ -41,10 +41,7 @@ class RequestModel(object):
 
 
 class Request(object):
-    def __init__(
-        self,
-        run_timeout: int,
-    ):
+    def __init__(self, run_timeout: int):
         self._run_timeout: int = run_timeout
         self._response_num_dict: Dict[int, int] = {
             Constant.DECLARE_REQUEST: Constant.DECLARE_RESPONSE,
@@ -72,7 +69,7 @@ class Request(object):
             client_model.nonce_set.add(nonce)
 
     async def dispatch(self, request: RequestModel) -> ResponseModel:
-        logging.debug(f"get request data:{request} from {request.conn.peer}")
+        logging.debug(f"get request data:%s from %s", request, request.conn.peer)
 
         response_num: Optional[int] = self._response_num_dict.get(request.request_num, Constant.SERVER_ERROR_RESPONSE)
 
@@ -132,7 +129,7 @@ class Request(object):
             if client_model.crypto is not MISS_OBJECT:
                 # declare will gen new crypto and replace
                 resp_model.result = client_model.crypto.encrypt_object(
-                    {"timestamp": int(time.time()), "nonce": gen_id(10), "client_id": client_model.client_id}
+                    {"timestamp": int(time.time()), "nonce": gen_random_time_id(), "client_id": client_model.client_id}
                 )
                 client_model.crypto = aes_manager.add_crypto(client_model.client_id)
             else:
@@ -148,37 +145,38 @@ class Request(object):
 
             # root func only called by local client
             if method_name.startswith("_root_") and request.conn.peer[0] != "127.0.0.1":
-                if request.header.get("programming_language") == Constant.PROGRAMMING_LANGUAGE:
+                if request.header.get("user_agent") == Constant.USER_AGENT:
                     exc, exc_info = parse_error(FuncNotFoundError())
                     resp_model.header["status_code"] = FuncNotFoundError.status_code
                     resp_model.result = {"exc": exc, "exc_info": exc_info}
                 else:
                     resp_model.exception = FuncNotFoundError()
-            new_call_id, result = await self.msg_handle(request.header, call_id, method_name, param, client_model)
-            if isinstance(result, Exception):
-                if request.header.get("programming_language") == Constant.PROGRAMMING_LANGUAGE:
-                    exc, exc_info = parse_error(result)
-                    resp_model.header["status_code"] = RpcRunTimeError.status_code
-                    resp_model.result = {"exc": exc, "exc_info": exc_info}
-                else:
-                    resp_model.exception = RpcRunTimeError(str(result))
             else:
-                resp_model.result = {"call_id": new_call_id, "method_name": method_name, "result": result}
+                new_call_id, result = await self.msg_handle(request.header, call_id, method_name, param, client_model)
+                if isinstance(result, Exception):
+                    if request.header.get("user_agent") == Constant.USER_AGENT:
+                        exc, exc_info = parse_error(result)
+                        resp_model.header["status_code"] = RpcRunTimeError.status_code
+                        resp_model.result = {"exc": exc, "exc_info": exc_info}
+                    else:
+                        resp_model.exception = RpcRunTimeError(str(result))
+                else:
+                    resp_model.result = {"call_id": new_call_id, "method_name": method_name, "result": result}
         elif request.request_num == Constant.DROP_REQUEST:
             call_id = decrypt_body["call_id"]
             client_manager.destroy_client_model(client_model.client_id)
             resp_model.result = {"call_id": call_id, "result": 1}
 
         if client_model.crypto is not MISS_OBJECT and type(resp_model.result) is dict:
-            resp_model.result.update(dict(timestamp=int(time.time()), nonce=gen_id(10)))
+            resp_model.result.update(dict(timestamp=int(time.time()), nonce=gen_random_time_id()))
             resp_model.result = client_model.crypto.encrypt_object(resp_model.result)
         return resp_model
 
     async def msg_handle(self, header: dict, call_id: int, method_name: str, param: str, client_model: "ClientModel"):
         # really request handle
         method: Callable = func_manager.func_dict.get(method_name)
-        version: str = header.get("version")
-        programming_language: str = header.get("programming_language")
+        # version: str = header.get("version")
+        user_agent: str = header.get("user_agent")
         try:
             if call_id in client_model.generator_dict:
                 try:
@@ -192,20 +190,21 @@ class Request(object):
                     result = e
             else:
                 if asyncio.iscoroutinefunction(method):
-                    result: Any = await asyncio.wait_for(method(*param), self._run_timeout)
+                    coroutine: Coroutine = method(*param)
                 else:
-                    result: Any = await get_event_loop().run_in_executor(None, method, *param)
+                    coroutine: Coroutine = get_event_loop().run_in_executor(None, method, *param)
+                result: Any = await asyncio.wait_for(coroutine, self._run_timeout)
 
                 if inspect.isgenerator(result):
-                    if programming_language != Constant.PROGRAMMING_LANGUAGE:
-                        result = ProtocolError(f"{programming_language} not support generator")
+                    if user_agent != Constant.USER_AGENT:
+                        result = ProtocolError(f"{user_agent} not support generator")
                     else:
                         call_id = id(result)
                         client_model.generator_dict[call_id] = result
                         result = next(result)
                 elif inspect.isasyncgen(result):
-                    if programming_language != Constant.PROGRAMMING_LANGUAGE:
-                        result = ProtocolError(f"{programming_language} not support generator")
+                    if user_agent != Constant.USER_AGENT:
+                        result = ProtocolError(f"{user_agent} not support generator")
                     else:
                         call_id = id(result)
                         client_model.generator_dict[call_id] = result
